@@ -6,3 +6,7 @@ COOKIECUTTER_DIRECTORY = 'cookiecutter_directory'
 COOKIECUTTER_CONTEXT = 'cookiecutter_context'
 
 CLI_EPILOG = 'Project Homepage: https://github.com/jedie/manageprojects'
+
+FORMAT_PY_FILE_DARKER_PREFIXES = 'E302,E303'
+FORMAT_PY_FILE_DEFAULT_MIN_PYTON_VERSION = '3.9'
+FORMAT_PY_FILE_DEFAULT_MAX_LINE_LENGTH = 119
